@@ -1,33 +1,13 @@
 from abc import abstractmethod
-from typing import Any, Dict, List, Optional
+from typing import Any, List, Optional
 
 from pydantic import BaseModel, PrivateAttr
 
 from obsei.misc import gpu_util
+from obsei.payload import TextPayload
 from obsei.workflow.base_store import BaseStore
 
 
-class AnalyzerRequest(BaseModel):
-    processed_text: str
-    source_name: str = "Undefined"
-    meta: Optional[Dict[str, Any]] = None
-
-
-class AnalyzerResponse(BaseModel):
-    processed_text: str
-    segmented_data: Optional[Dict[str, Any]] = None
-    meta: Optional[Dict[str, Any]] = None
-    source_name: Optional[str] = None
-
-    def to_dict(self):
-        return {
-            "processed_text": self.processed_text,
-            "segmented_data": self.segmented_data,
-            "meta": self.meta,
-            "source_name": self.source_name,
-        }
-
-
 class BaseAnalyzerConfig(BaseModel):
     TYPE: str = "Base"
 
@@ -40,6 +20,7 @@ class BaseAnalyzer(BaseModel):
     TYPE: str = "Base"
     store: Optional[BaseStore] = None
     device: str = "auto"
+    batch_size: int = 64
 
     """
         auto: choose gpu if present else use cpu
@@ -50,14 +31,15 @@ class BaseAnalyzer(BaseModel):
     def __init__(self, **data: Any):
         super().__init__(**data)
         self._device_id = gpu_util.get_device_id(self.device)
+        self.batch_size = 4 if self._device_id == 0 else self.batch_size
 
     @abstractmethod
     def analyze_input(
         self,
-        source_response_list: List[AnalyzerRequest],
-        analyzer_config: BaseAnalyzerConfig,
-        **kwargs
-    ) -> List[AnalyzerResponse]:
+        source_response_list: List[TextPayload],
+        analyzer_config: Optional[BaseAnalyzerConfig] = None,
+        **kwargs,
+    ) -> List[TextPayload]:
         pass
 
     class Config:
