@@ -1,16 +1,17 @@
 from abc import abstractmethod
 from typing import Any, Dict, List, Optional
 
+from pydantic import Field
 from pydantic.main import BaseModel
 
-from obsei.analyzer.base_analyzer import AnalyzerResponse
+from obsei.payload import TextPayload
 from obsei.workflow.base_store import BaseStore
 
 
 class Convertor(BaseModel):
     def convert(
         self,
-        analyzer_response: AnalyzerResponse,
+        analyzer_response: TextPayload,
         base_payload: Optional[Dict[str, Any]] = None,
         **kwargs
     ) -> dict:
@@ -37,17 +38,13 @@ class BaseSinkConfig(BaseModel):
 
 
 class BaseSink(BaseModel):
-    convertor: Optional[Convertor] = None
+    convertor: Convertor = Field(Convertor())
     store: Optional[BaseStore] = None
 
-    def __init__(self, **data: Any):
-        super().__init__(**data)
-        self.convertor = self.convertor or Convertor()
-
     @abstractmethod
     def send_data(
         self,
-        analyzer_responses: List[AnalyzerResponse],
+        analyzer_responses: List[TextPayload],
         config: BaseSinkConfig,
         **kwargs
     ):
