@@ -9,7 +9,7 @@ from dateutil import parser
 
 from obsei.sink.base_sink import Convertor
 from obsei.sink.http_sink import HttpSink, HttpSinkConfig
-from obsei.analyzer.base_analyzer import AnalyzerResponse
+from obsei.payload import TextPayload
 from obsei.misc.utils import flatten_dict
 
 logger = logging.getLogger(__name__)
@@ -22,7 +22,7 @@ IST_TZ = pytz.timezone("Asia/Kolkata")
 class PayloadConvertor(Convertor):
     def convert(
         self,
-        analyzer_response: AnalyzerResponse,
+        analyzer_response: TextPayload,
         base_payload: Optional[Dict[str, Any]] = None,
         **kwargs,
     ) -> Dict[str, Any]:
@@ -39,7 +39,7 @@ class PayloadConvertor(Convertor):
         text = ""
         tweet_id = None
         created_at_str = None
-        classification_list = []
+        classification_list: List[str] = []
 
         flat_dict = flatten_dict(analyzer_response.to_dict())
         for k, v in flat_dict.items():
@@ -66,7 +66,7 @@ class PayloadConvertor(Convertor):
                 .strftime("%Y-%m-%d %H:%M:%S")
             )
 
-        tweet_url = user_url + "/status/" + tweet_id
+        tweet_url = f"{user_url}/status/{tweet_id}"
         # Sentiment rules
         if negative > 8.0:
             sentiment = "Strong Negative"
@@ -108,9 +108,9 @@ class DailyGetSink(HttpSink):
     def __init__(self, convertor: Convertor = PayloadConvertor(), **data: Any):
         super().__init__(convertor=convertor, **data)
 
-    def send_data(
+    def send_data(  # type: ignore[override]
         self,
-        analyzer_responses: List[AnalyzerResponse],
+        analyzer_responses: List[TextPayload],
         config: DailyGetSinkConfig,
         **kwargs,
     ):
