@@ -1,12 +1,10 @@
-import json
 from copy import deepcopy
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Optional
 from urllib.request import Request, urlopen
 
-from obsei.misc.utils import datetime_handler
+from obsei.misc.utils import obj_to_json
 from obsei.sink.base_sink import BaseSink, BaseSinkConfig, Convertor
-from obsei.analyzer.base_analyzer import AnalyzerResponse
-
+from obsei.payload import TextPayload
 
 DEFAULT_HEADERS = {"Content-type": "application/json"}
 
@@ -14,20 +12,20 @@ DEFAULT_HEADERS = {"Content-type": "application/json"}
 class HttpSinkConfig(BaseSinkConfig):
     TYPE: str = "Http"
     url: str
-    headers: Dict[str, Any] = None
-    base_payload: Dict[str, Any] = None
+    headers: Optional[Dict[str, Any]] = None
+    base_payload: Optional[Dict[str, Any]] = None
     # analyzer_output to payload mapping
-    payload_mapping: Dict[str, List[str]] = None
-    field_conversion: Dict[str, str] = None
+    payload_mapping: Optional[Dict[str, List[str]]] = None
+    field_conversion: Optional[Dict[str, str]] = None
 
 
 class HttpSink(BaseSink):
     def __init__(self, convertor: Convertor = Convertor(), **data: Any):
         super().__init__(convertor=convertor, **data)
 
-    def send_data(
+    def send_data(  # type: ignore[override]
         self,
-        analyzer_responses: List[AnalyzerResponse],
+        analyzer_responses: List[TextPayload],
         config: HttpSinkConfig,
         **kwargs
     ):
@@ -47,10 +45,7 @@ class HttpSink(BaseSink):
             )
 
         for payload in payloads:
-            json_data = json.dumps(
-                payload, default=datetime_handler, ensure_ascii=False
-            ).encode("utf8")
-            req = Request(config.url, data=json_data, headers=headers)
+            req = Request(config.url, data=obj_to_json(payload), headers=headers)
             response = urlopen(req)
             responses.append(response)
 
