@@ -3,13 +3,13 @@ import imaplib
 import logging
 from datetime import datetime
 from email.header import decode_header
-from mailbox import Message
+from email.message import Message
 from typing import Any, Dict, List, Optional
 
 import pytz
 from pydantic import BaseSettings, Field, PrivateAttr, SecretStr
 
-from obsei.analyzer.base_analyzer import AnalyzerRequest
+from obsei.payload import TextPayload
 from obsei.misc.utils import (
     DATETIME_STRING_PATTERN,
     DEFAULT_LOOKUP_PERIOD,
@@ -22,8 +22,8 @@ logger = logging.getLogger(__name__)
 
 
 class EmailCredInfo(BaseSettings):
-    username: Optional[SecretStr] = Field(None, env="email_username")
-    password: Optional[SecretStr] = Field(None, env="email_password")
+    username: SecretStr = Field(env="email_username")
+    password: SecretStr = Field(env="email_password")
 
 
 class EmailConfig(BaseSourceConfig):
@@ -39,16 +39,13 @@ class EmailConfig(BaseSourceConfig):
     imap_server: str
     imap_port: Optional[int] = None
     download_attachments: Optional[bool] = False
-    mailboxes: Optional[List[str]] = Field(["INBOX"])
-    cred_info: Optional[EmailCredInfo] = None
+    mailboxes: List[str] = Field(["INBOX"])
+    cred_info: EmailCredInfo = Field(EmailCredInfo())
     lookup_period: Optional[str] = None
 
     def __init__(self, **data: Any):
         super().__init__(**data)
 
-        if self.cred_info is None:
-            self.cred_info = EmailCredInfo()
-
         if self.imap_port:
             self._imap_client = imaplib.IMAP4_SSL(
                 host=self.imap_server, port=self.imap_port
@@ -77,12 +74,16 @@ class EmailSource(BaseSource):
         # clean text for creating a folder
         return "".join(c if c.isalnum() else "_" for c in text)
 
-    def lookup(self, config: EmailConfig, **kwargs) -> List[AnalyzerRequest]:
-        source_responses: List[AnalyzerRequest] = []
+    def lookup(self, config: EmailConfig, **kwargs) -> List[TextPayload]:  # type: ignore[override]
+        source_responses: List[TextPayload] = []
 
         # Get data from state
         id: str = kwargs.get("id", None)
-        state: Dict[str, Any] = None if id is None else self.store.get_source_state(id)
+        state: Optional[Dict[str, Any]] = (
+            None
+            if id is None or self.store is None
+            else self.store.get_source_state(id)
+        )
         update_state: bool = True if id else False
         state = state or dict()
 
@@ -116,7 +117,7 @@ class EmailSource(BaseSource):
 
             state[mailbox] = mailbox_stat
 
-            num_of_emails = int(messages[0])
+            num_of_emails = int(str(messages[0]))
 
             # Read in reverse order means latest emails first
             # Most of code is borrowed from https://www.thepythoncode.com/article/reading-emails-in-python and
@@ -246,9 +247,9 @@ class EmailSource(BaseSource):
                             last_index = email_meta["message_id"]
 
                         source_responses.append(
-                            AnalyzerRequest(
+                            TextPayload(
                                 processed_text="\n".join(
-                                    [email_meta.get("subject"), email_content]
+                                    [email_meta.get("subject", ""), email_content]
                                 ),
                                 meta=email_meta,
                                 source_name=self.NAME,
@@ -263,7 +264,7 @@ class EmailSource(BaseSource):
             )
             mailbox_stat["since_comment_id"] = last_index
 
-        if update_state:
+        if update_state and self.store:
             self.store.update_source_state(workflow_id=id, state=state)
 
         return source_responses
@@ -278,5 +279,5 @@ class EmailSource(BaseSource):
         value, encoding = decode_header(header[key])[0]
         if isinstance(value, bytes):
             # if it's a bytes, decode to str
-            value = value.decode(encoding)
+            return "" if not encoding else value.decode(encoding)
         return value
