@@ -1,5 +1,5 @@
 import logging
-from datetime import datetime
+from datetime import datetime, timezone
 from typing import Any, Dict, List, Optional
 
 import mmh3
@@ -7,7 +7,7 @@ from pydantic import PrivateAttr
 from reddit_rss_reader.reader import RedditContent, RedditRSSReader
 
 from obsei.source.base_source import BaseSource, BaseSourceConfig
-from obsei.analyzer.base_analyzer import AnalyzerRequest
+from obsei.payload import TextPayload
 from obsei.misc.utils import (
     DATETIME_STRING_PATTERN,
     DEFAULT_LOOKUP_PERIOD,
@@ -45,16 +45,22 @@ class RedditScrapperConfig(BaseSourceConfig):
 class RedditScrapperSource(BaseSource):
     NAME: Optional[str] = "RedditScrapper"
 
-    def lookup(self, config: RedditScrapperConfig, **kwargs) -> List[AnalyzerRequest]:
-        source_responses: List[AnalyzerRequest] = []
+    def lookup(self, config: RedditScrapperConfig, **kwargs) -> List[TextPayload]:  # type: ignore[override]
+        source_responses: List[TextPayload] = []
 
         # Get data from state
         id: str = kwargs.get("id", None)
-        state: Dict[str, Any] = None if id is None else self.store.get_source_state(id)
+        state: Optional[Dict[str, Any]] = (
+            None
+            if id is None or self.store is None
+            else self.store.get_source_state(id)
+        )
         update_state: bool = True if id else False
         state = state or dict()
 
-        scrapper_stat: Dict[str, Any] = state.get(config.url_id, dict())
+        scrapper_stat: Dict[str, Any] = (
+            dict() if not config.url_id else state.get(config.url_id, dict())
+        )
         lookup_period: str = scrapper_stat.get("since_time", config.lookup_period)
         lookup_period = lookup_period or DEFAULT_LOOKUP_PERIOD
         if len(lookup_period) <= 5:
@@ -66,7 +72,8 @@ class RedditScrapperSource(BaseSource):
 
         since_id: Optional[str] = scrapper_stat.get("since_id", None)
         last_index = since_id
-        state[config.url_id] = scrapper_stat
+        if config.url_id:
+            state[config.url_id] = scrapper_stat
 
         reddit_data: Optional[List[RedditContent]] = None
         try:
@@ -80,15 +87,17 @@ class RedditScrapperSource(BaseSource):
 
         for reddit in reddit_data:
             source_responses.append(
-                AnalyzerRequest(
+                TextPayload(
                     processed_text=f"{reddit.title}. {reddit.extracted_text}",
                     meta=reddit.__dict__,
                     source_name=self.NAME,
                 )
             )
 
-            if last_since_time is None or last_since_time < reddit.updated:
-                last_since_time = reddit.updated
+            comment_time = reddit.updated["at"].replace(tzinfo=timezone.utc)
+
+            if last_since_time is None or last_since_time < comment_time:
+                last_since_time = comment_time
             if last_index is None:
                 # Assuming list is sorted based on time
                 last_index = reddit.id
@@ -96,7 +105,7 @@ class RedditScrapperSource(BaseSource):
         scrapper_stat["since_time"] = last_since_time.strftime(DATETIME_STRING_PATTERN)
         scrapper_stat["since_id"] = last_index
 
-        if update_state:
+        if update_state and self.store:
             self.store.update_source_state(workflow_id=id, state=state)
 
         return source_responses
