@@ -4,7 +4,7 @@ from typing import Any, Dict, List, Optional
 from praw import Reddit
 from pydantic import BaseSettings, Field, PrivateAttr, SecretStr
 
-from obsei.analyzer.base_analyzer import AnalyzerRequest
+from obsei.payload import TextPayload
 from obsei.misc.utils import (
     DATETIME_STRING_PATTERN,
     DEFAULT_LOOKUP_PERIOD,
@@ -36,15 +36,12 @@ class RedditConfig(BaseSourceConfig):
     post_ids: Optional[List[str]] = None
     lookup_period: Optional[str] = None
     include_post_meta: Optional[bool] = True
-    post_meta_field: Optional[str] = "post_meta"
-    cred_info: Optional[RedditCredInfo] = None
+    post_meta_field: str = "post_meta"
+    cred_info: RedditCredInfo = Field(RedditCredInfo())
 
     def __init__(self, **data: Any):
         super().__init__(**data)
 
-        if self.cred_info is None:
-            self.cred_info = RedditCredInfo()
-
         self._reddit_client = Reddit(
             client_id=self.cred_info.client_id.get_secret_value(),
             client_secret=self.cred_info.client_secret.get_secret_value(),
@@ -68,12 +65,16 @@ class RedditConfig(BaseSourceConfig):
 class RedditSource(BaseSource):
     NAME: str = "Reddit"
 
-    def lookup(self, config: RedditConfig, **kwargs) -> List[AnalyzerRequest]:
-        source_responses: List[AnalyzerRequest] = []
+    def lookup(self, config: RedditConfig, **kwargs) -> List[TextPayload]:  # type: ignore[override]
+        source_responses: List[TextPayload] = []
 
         # Get data from state
         id: str = kwargs.get("id", None)
-        state: Dict[str, Any] = None if id is None else self.store.get_source_state(id)
+        state: Optional[Dict[str, Any]] = (
+            None
+            if id is None or self.store is None
+            else self.store.get_source_state(id)
+        )
         update_state: bool = True if id else False
         state = state or dict()
 
@@ -132,7 +133,7 @@ class RedditSource(BaseSource):
                 text = "".join(text_from_html(comment_data["body_html"]))
 
                 source_responses.append(
-                    AnalyzerRequest(
+                    TextPayload(
                         processed_text=text, meta=comment_data, source_name=self.NAME
                     )
                 )
@@ -140,7 +141,7 @@ class RedditSource(BaseSource):
             post_stat["since_time"] = last_since_time.strftime(DATETIME_STRING_PATTERN)
             post_stat["since_comment_id"] = last_index
 
-        if update_state:
+        if update_state and self.store is not None:
             self.store.update_source_state(workflow_id=id, state=state)
 
         return source_responses
