@@ -1,5 +1,6 @@
 from obsei.analyzer.classification_analyzer import ClassificationAnalyzerConfig
-from obsei.analyzer.base_analyzer import AnalyzerRequest
+from obsei.analyzer.base_analyzer import BaseAnalyzerConfig
+from obsei.payload import TextPayload
 
 GOOD_TEXT = """If anyone is interested... these are our hosts. I can’t recommend them enough, Abc & Pbc.
 
@@ -16,7 +17,7 @@ def test_zero_shot_analyzer(zero_shot_analyzer):
     labels = ["facility", "food", "comfortable", "positive", "negative"]
 
     source_responses = [
-        AnalyzerRequest(processed_text=text, source_name="sample") for text in TEXTS
+        TextPayload(processed_text=text, source_name="sample") for text in TEXTS
     ]
     analyzer_responses = zero_shot_analyzer.analyze_input(
         source_response_list=source_responses,
@@ -33,7 +34,7 @@ def test_zero_shot_analyzer(zero_shot_analyzer):
 
 def test_vader_analyzer(vader_analyzer):
     source_responses = [
-        AnalyzerRequest(processed_text=text, source_name="sample") for text in TEXTS
+        TextPayload(processed_text=text, source_name="sample") for text in TEXTS
     ]
     analyzer_responses = vader_analyzer.analyze_input(
         source_response_list=source_responses
@@ -49,21 +50,20 @@ def test_vader_analyzer(vader_analyzer):
 
 def test_ner_analyzer(ner_analyzer):
     source_responses = [
-        AnalyzerRequest(
-            processed_text="My name is Lalit and I live in Berlin, Germany.",
+        TextPayload(
+            processed_text="My name is Sam and I live in Berlin, Germany.",
             source_name="sample",
         )
     ]
     analyzer_responses = ner_analyzer.analyze_input(
-        source_response_list=source_responses
+        source_response_list=source_responses,
     )
-
     assert len(analyzer_responses) == 1
 
     entities = analyzer_responses[0].segmented_data["data"]
     matched_count = 0
     for entity in entities:
-        if entity["word"] == "Lalit" and entity["entity_group"] == "PER":
+        if entity["word"] == "Sam" and entity["entity_group"] == "PER":
             matched_count = matched_count + 1
         elif entity["word"] == "Berlin" and entity["entity_group"] == "LOC":
             matched_count = matched_count + 1
